@@ -116,7 +116,7 @@ class UserManager(BaseUserManager):
         return user
 
 
-class User(AbstractBaseUser, PermissionsMixin, TimeStampedModel):
+class BaseUserModel(AbstractBaseUser, PermissionsMixin, TimeStampedModel):
     display_name = models.CharField(max_length=100)
     email = models.EmailField(unique=True)
     is_active = models.BooleanField(default=False)
@@ -127,7 +127,7 @@ class User(AbstractBaseUser, PermissionsMixin, TimeStampedModel):
     objects = UserManager()
 
     class Meta:
-        app_label = 'authentication'
+        abstract = True
 
     def get_full_name(self):
         return self.display_name
@@ -144,3 +144,10 @@ class User(AbstractBaseUser, PermissionsMixin, TimeStampedModel):
     def get_username(self):
         return self.email
     username = property(get_username)
+
+
+if getattr(settings, 'AUTH_USER_MODEL') == 'authentication.User':
+    class User(BaseUserModel):
+
+        class Meta:
+            app_label = 'authentication'
