@@ -3,6 +3,7 @@
 from django.views.generic import (
     CreateView,
     DeleteView,
+    DetailView,
     FormView,
     ListView,
     TemplateView,
@@ -20,6 +21,10 @@ class ProtectedDeleteView(LoginRequiredMixin, DeleteView):
     pass
 
 
+class ProtectedDetailView(LoginRequiredMixin, DetailView):
+    pass
+
+
 class ProtectedFormView(LoginRequiredMixin, FormView):
     pass
 
